
function iguana.checkServerStatus(args)
   local srv = args.server
   local usr = args.username
   local pas = args.password
   
   return xml.parse{data=net.http.get{
         live=true, timeout=60,
         url=srv..[[/status.html]],
         auth={username=usr, password=pas},
         parameters={Format='xml'}}
   }
end --end of checkServer


function iguana.restartChannel(args)
   local srv = args.server
   local usr = args.username
   local pas = args.password
   local nme = args.channel
  --restart channel
   net.http.get{url=srv..[[/status.html]],
      auth={username=usr, password=pas},
      parameters={ChannelAction='Start', ChannelName=nme},
      live=false
   }
  --log a warning SETUP AN EMAIL NOTIFICATION IF YOU WANT ALERTED
   iguana.logWarning([[Channel ]]..nme..[[ is down and being restarted.]])
end --end of restartChannels
















help_checkServerStatus = {
   Title="iguana.checkServerStatus";
   Usage=[[iguana.checkServerStatus{server=< value > , username=< value >, password=< value >}]],
   Desc=[[Checks the Iguana server to get all the channels and their statuses.
   ]];
   ["Returns"] = {
      {Desc="Table with all channel names and statuses."},
   };
   ParameterTable= true,
   Parameters= {
      {server= {Desc=[[The Iguana server URL (ex. 'http://192.168.1.1:6543').]]}},
      {username= {Desc='Iguana server username with authorization to start channels.'}},
      {password= {Desc='Iguana server user password needed to authorize channel start.'}}
   };
   Examples={
      [[iguana.checkServerStatus{
      server='192.168.1.1:6543', 
      username='admin', 
      password='password'
      }
   ]],
   };
   SeeAlso={
      {
         Title="Monitoring an Iguana Instance with Iguana",
         Link="http://wiki.interfaceware.com/190.html"
      },
      {
         Title="Starting and Stopping Channels Using a Web URL",
         Link="http://www.interfaceware.com/manual/starting_and_stopping_channels_using_a_web_url.html"
      }
   }
}


help_restartChannel = {
   Title="iguana.restartChannel";
   Usage=[[iguana.restartChannel{server=< value > , username=< value >, password=< value >, channel=< value >}]],
   Desc=[[Restarts the channel that you specify on the server you designate as well as logs
   a warning into the logs identifying the channel that was restarted which is good for setting up and receiving email notifications..
   ]];
   ["Returns"] = {
      {Desc="nothing."},
   };
   ParameterTable= true,
   Parameters= {
      {server= {Desc=[[The Iguana server URL (ex. 'http://192.168.1.1:6543').]]}},
      {username= {Desc='Iguana server username with authorization to start channels.'}},
      {password= {Desc='Iguana server user password needed to authorize channel start.'}},
      {channel= {Desc='Iguana Channel name, as a string, to start.'}}
   };
   Examples={
      [[iguana.restartChannel{
      server='192.168.1.1:6543', 
      username='admin', 
      password='password',
      channel='Iguana Channel Name'}
   ]],
   };
   SeeAlso={
      {
         Title="Monitoring an Iguana Instance with Iguana",
         Link="http://wiki.interfaceware.com/190.html"
      },
      {
         Title="Starting and Stopping Channels Using a Web URL",
         Link="http://www.interfaceware.com/manual/starting_and_stopping_channels_using_a_web_url.html"
      }
   }
}


help.set{input_function=iguana.checkServerStatus,help_data=help_checkServerStatus}
help.set{input_function=iguana.restartChannel, help_data=help_restartChannel}
